@@ -57,7 +57,7 @@ pub mod BTW {
 
 pub mod title;
 
-#[cfg(feature = "archlinux")]
+#[cfg(all(feature = "arch", feature = "linux"))]
 pub mod how_to_install_archlinux;
 
 pub mod Español {}
